import request from "@/utils/request";

// 查询计费模板列表
export function listTemplate(query) {
  return request({
    url: "/billing/template/list",
    method: "get",
    params: query,
  });
}

// 增加计费模板
export function addBillingTemplate(data) {
  console.log("增加计费模板", JSON.stringify(data));
  return request({
    method: "post",
    url: "/billing/template/createBillingTemplate",
    data,
  });
}

// 更新计费模板
export function updateBillingTemplate(data) {
  console.log("更新计费模板", JSON.stringify(data));
  return request({
    method: "post",
    url: "/billing/template/updateBillingTemplate",
    data,
  });
}

// 查询计费模板详细
export function getTemplate(id) {
  return request({
    url: "/billing/template/" + id,
    method: "get",
  });
}

// 新增计费模板
export function addTemplate(data) {
  return request({
    url: "/billing/template",
    method: "post",
    data: data,
  });
}

// 修改计费模板
export function updateTemplate(data) {
  return request({
    url: "/billing/template",
    method: "put",
    data: data,
  });
}

// 删除计费模板
export function delTemplate(id) {
  return request({
    url: "/billing/template/" + id,
    method: "delete",
  });
}

// 查询公共计费模板
export function queryPublicBillingTemplateList() {
  return request({
    url: "/billing/template/queryPublicBillingTemplateList",
    method: "get",
  });
}

// 查询站点计费模板
export function queryStationBillingTemplateList(stationId) {
  return request({
    url: "/billing/template/queryStationBillingTemplateList/" + stationId,
    method: "get",
  });
}

// 站点导入计费模板接口
export function stationImportBillingTemplate(data) {
  return request({
    url: "/billing/template/stationImportBillingTemplate",
    method: "post",
    data: data,
  });
}

// 发布计费模板
export function publishBillingTemplate(data) {
  return request({
    url: "/billing/template/publishBillingTemplate",
    method: "post",
    data: data,
  });
}

// 查询全部计费模板
